//Создание задачи диспетчерского вызова прочих задач
function LocalSolveAllTasks(ErrorFunction,..//Функция нештатных ситуаций
                            DisplayFunction,..//Функция отправки сообщения
                            ProjectName..//Имя проекта
                            )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 3 then
        error('The function LocalSolveAllTasks takes 3 arguments');
    end
    
    //Обрабатываем функцию отображения
    select type(DisplayFunction)
    case 10 then
        execstr('displayFunction = ' + DisplayFunction);
    case 15 then
        //Получаем имя функции отображения и ее параметры
        dFunction = DisplayFunction(1);
        dFunctionParametrs = DisplayFunction(2:$);
        
        //Приводим имя функции к типу функции
        execstr('dFunction = ' + dFunction);
        
        //Формируем функцию вызова
        function displayFunction(askStr)
            dFunction(askStr,dFunctionParametrs(:));
        endfunction
    end
    
    //Обрабатываем функцию ошибок
    select type(ErrorFunction)
    case 10 then
        execstr('errorFunction = ' + ErrorFunction);
    case 15 then
        //Получаем имя функции отображения и ее параметры
        eFunction = ErrorFunction(1);
        eFunctionParametrs = ErrorFunction(2:$);
        
        //Приводим имя функции к типу функции
        execstr('eFunction = ' + eFunction);
        
        //Формируем функцию вызова
        function errorFunction(askStr)
            eFunction(askStr,eFunctionParametrs(:));
        endfunction
    end
    
    //Глобальная переменная сообщений от только что решенной задачи
    global NowSolvedTaskMsg;
    
    //Получаем доступные задачи
    EnabledTasks = GetEnabledTasks(ProjectName,%f);
    
    //Запускаем по очереди задачи на решение
    while ~isempty(EnabledTasks)
        //Выводим доступные задачи
        displayFunction('EnabledTasks: ' + strcat(EnabledTasks,','));
        
        //Имя текущей решаемой задачи
        CurrentTask = EnabledTasks(1);
        
        //Запускаем первую задачу на решение
        [errTasks,..//Ошибки задач
         errMsgTasks..//Сообщения об ошибках задач
         ]=ExecuteTasks(CurrentTask,ProjectName,%f);
        if errTasks ~= 0 then
            errorFunction('Cannot solving task ' + CurrentTask + ': ' + errMsgTasks);
            
            return;
        end
        
        //Регистрируем решенную задачу
        [err,msg] = RegisteredSolvedTaskFromRezult(CurrentTask,..
                                                   NowSolvedTaskMsg,..
                                                   ProjectName,%f);
        if err ~= 0 then
            errorFunction(msg);
            
            return;
        end
        
        //Выводим сообщение об успешном решении задач
        displayFunction('The task ' + CurrentTask + ' was solved sucsessfully!');
    
        //Получаем доступные задачи
        EnabledTasks = GetEnabledTasks(ProjectName,%f);
    end
endfunction
